dPrior = function(lrf, Par=list(agam=1,rgam=1), ln=TRUE) {

####################################################################
#
# Internal use only.  Not currently utilized.
#
# Gamma random field prior: log density function w.r.t. Lebesgue measure
# [Note: w.r.t. UNIFORM measure would pick up factor of area*length(lrf)]
#
  
  if(class(lrf)!="Lrf") stop("GammaPrior: 1st arg must be Lrf object");
  val = log(Par$agam)*length(lrf) - sum(log(lrf@z)) - Par$rgam*sum(lrf@z);
  ifelse(ln, val, exp(val));
}

rPrior = function(
  poly,                      # the polygon.
  M,                         # The number of atoms to be drawn.  If not
                             # specified, the num. of atoms is drawn from
                             # its gamma prior.
  MaxM,                      # The max number of atoms.  If this is used
                             # then a warning is generated.
  Par=list(agam=1,rgam=1),   # parameters of prior for num. of atoms.
  eps=0,                     # epsilon truncation for numerical stability.
  frac=0.01,                 # an alternative specification for the same
                             # truncation.
  oldLrf                     # if atoms are specified with oldLrf, then
                             # the new atoms are concatenated to the old.
  ) {
  
####################################################################
#
# Internal use only.  Not currently utilized.
#
# Draw from the Gamma random field prior: generate random draw of size M 
# within polygon poly.
#
  
  # Gamma random field prior: generate random draw of size N
  if(missing(oldLrf)) {            # If old lrf not specified,
                                   # draw new.
    if(missing(poly))              # If poly not specified, default to unit square.
      poly = Poly(Vec(x=c(0,1,1,0,0),y=c(0,0,1,1,0)));
    tau = 0.0;
  } else {                         # Extend existing lrf w/more pts
    if(missing(eps))  eps  = oldLrf@eps;
    if(missing(poly)) poly = oldLrf@bdy;
    tau = oldLrf@tau;
  }
  if(missing(M) || !is.integer(M) || M<1) {  # If M not specified
    if(missing(eps) || eps<=0) {   # Omit fraction frac of mass
      frac = max(0.0001, min(0.75, frac));   # Limit range of frac
      eps = -log(1-frac)/Par$rgam;      # About frac/Par$rgam, if frac small
    }
    EM = Par$agam*poly@area * e1(Par$rgam*eps);    # Exp num E[M] jmps > eps
print( paste( "EM = ", EM, "; Par$agam = ", Par$agam, "; Par$rgam = ", Par$rgam, "; area = ", poly@area,
             "e1(Par$rgam*eps) = ", e1(Par$rgam*eps) ) );
    if(!missing(MaxM) && EM > MaxM) {
      warning(paste("Reducing EM=",round(EM,2)," to JmpMax=",MaxM,sep=""));
      EM = MaxM;
    }
    M  = max(1,rpois(1,EM));
    r  = tau+sort(runif(n=M,min=0,max=EM));  # Jump times, cont'l on M
  } else {
    r  = tau+cumsum(rexp(n=M));        # Jump times of std Poi proc
  }
  rp = rPoly(M, poly);                 # M pts drawn uniformly from
  x  = rp@x; y = rp@y;                 # interior of polygon "poly"
  u  = e1inv(r/(Par$agam*poly@area))/Par$rgam; # Levy proc mass sizes
  if(missing(oldLrf)) dm = Meas(Vec(x,y),u);
  else                dm = Meas(Vec(x,y),u,oldLrf);
  val = Lrf(dm, bdy=poly, eps=eps, tau=r[M]);
}

# Re-entry distribution and Levy distribution

dLevy = function(poly, xy, z, Par=list(agam=1,rgam=1), ln=TRUE) {

####################################################################
#
# Internal use only.  Not currently utilized.
# Levy density at xy,z (or LOG density if ln=TRUE)
#


  lpdf = sum(log(Par$agam/z)) - Par$rgam*sum(z);
  ifelse(ln,lpdf,exp(lpdf));
}

rBirth = function(
  N=1,
  lrf,           # The current set of atoms.  Just used here to get the
                 # polygon and epsilon (for truncation).
  sca=1,         # The scale for generating the weight of the new atom
  ln=TRUE        # Whether to return the log pdf or the pdf
  ) {
  
####################################################################
#
# Internal use only.  Not currently utilized.
# Generate N random atoms from birth dist'n; return (log) pdf
#

  xy  = rPoly(N, lrf@bdy);                  # New loc (x,y) unif in bdy gon
  z   = lrf@eps + rexp(n=N, scale=sca);     # New mass  z ~ eps+Ex(1/sca)
  pdf = sum(lrf@eps-z)/sca - N * log(sca*lrf@bdy@area);
  if(!ln) pdf = exp(pdf);
  list(xy=xy, z=z, pdf=pdf);                # COULD rtn Meas object dm...
}

dBirth = function(lrf, j, sca, ln=TRUE) {
# (log)pdf for birth dist'n at specified indices
  pdf = sum(lrf@eps-lrf@z[j])/sca - length(j) * log(sca*lrf@bdy@area);
  ifelse(ln, pdf, exp(pdf));
}

# Exponential Integral Function and its inverse (see A+S sec 5.1)
# Note this is only used in rPrior to draw initial MCMC draw, so
# is not critical.... the qchisq/pchisq approx'ns are good enough.

#e1    = function(x, d = 1e-9) {(2/d) * (1-pchisq(2*x, d))}
#e1inv = function(y, d = 1e-9) {qchisq(1-(d/2)*y, d)/2}
# The following work well for small x, large y... say, for x < 1 < y.
# A&S 5.1.53:

e1 = function(x) {      

####################################################################
#
# Internal use only.  Not currently utilized.
#
# Exponential integral function.
#
  -log(x) - 0.57721566 + x*(0.99999193 - x*(0.24991055 - x*
           (0.55199680 - x*(0.00976004 - x*(0.00107857)))));
}

e1inv = function(y) {   # AIJM van Dijk (2002)  

####################################################################
#
# Internal use only.  Not currently utilized.
#
# Inverse of the exponential integral function.
#
  
  t1 = exp(-y-0.577215665);
  t2 = exp(-2.216*y-0.722);
  t3 = exp(-6.547*y-2.481);
  return(t1+t2-t3);
  }
