// Compiled C subroutine to run the MCMC

#define TNT_BOUNDS_CHECK

#include "S.h"
#include "LevyMCMC.h"



extern "C"{

void MCMC(
     double *datX,                   // The data (x, z for each of datLen samples, where x is the location
     double *datZ,   long *datLen,   // and z is the measurement)
     char **OutLG, char **OutFL,     // The names of the log, fixed-length and variable-length files to be written
     char **OutVL,                    
     double *xlim,                    // The bounding region within which to fit the surface.  xlim should 
                                      // be a length-2 vectors
     long *ItnMax,     long *ItnBrn,  // ItnMax is the number of total iterations after burnin, while ItnBrn is 
                                      // the length of the burnin
     long *SavMax,     double *pX,    // SavMax is the maximum number of saved iterations.  The resulting thinning 
                                      // is approximately 
                                      // ItnMax / SavMax.  pX is a vector of the probabilities of proposing a move 
                                      // for each of the parameters:
                                      //     - prec: outcome (measurement) precision, conditional on a fixed z-surface
                                      //     - beta: the regression coefficients (not currently supported--should be zero)
                                      //     - birth: add a new atom
                                      //     - move: change the location and height of one of the existing atoms
                                      //     - remove: remove one of the atoms
     double *dX,       double *apre,  // dX is the step size for the proposal for each of the above move types.  apre and rpre
     double *rpre,     double *asigma,// dX is the step size for the proposal for each of the above move types.  asigma and rsigma
     double *rsigma,                  // are the parameters of the Gamma prior distribution for the precisions of the kernels.
     double *mbet,     double *sbet,  // mbet,sbet: the parameters of the normal prior distribution for the intercept parameter.
     double *pM,       long *pMlen,   // pM: the prior prob. vector for the multinomial prior on M.  pMlen: the length of pM
     double *agam,     double *rgam,  // agam and rgam are parameters of the Levy process prior for the spatial 
                                      // surface.
     double *temps, long *nTemps,     // The temperatures for the parallel tempering process
     long *symm,                      // whether a symmetric gamma Levy random field is to be used
                                      // (otherwise a gamma Levy r.f. is used)
     long *printStats)                // Whether or not to print summary statistics regarding the Markov chain 
                                      // acceptance rates etc.
{

  // Create an array of doubles for the temperatures
  int i, nTemps_ = (int) (*nTemps), pMlen_ = (int) (*pMlen);
  TNT::Array1D<double> tempArr ( nTemps_ ), pMarr( pMlen_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];
  for( i=0; i<pMlen_; i++ )
    pMarr[i] = pM[i];

  #ifdef DEBUG1
    printf("xlim = %f, %f, asigma = %f, rsigma = %f \n", xlim[0], xlim[1], (*asigma), (*rsigma));
    printf("datLen = %d\n", (int)(*datLen));
    std::cout << "temperatures: " << tempArr << "pM: " << pMarr << std::endl;
  #endif

  LevyMCMC *mcmc = new LevyMCMC(datX, datZ, (int) (*datLen), 
				(*OutLG), (*OutFL), (*OutVL), 
				xlim, (int) (*ItnMax), (int) (*ItnBrn), 
				(int) (*SavMax), pX, dX, (double) (*apre), 
				(double) (*rpre), (double) (*asigma), 
				(double) (*rsigma), 
				(double) (*mbet), (double) (*sbet),
				pMarr, (double) (*agam), 
				(double) (*rgam), tempArr,
				(bool) (*symm), (bool) (*printStats) );

  mcmc->doMCMC();

  //delete(mcmc);
  return;
}
          
}


