// Compiled C subroutine to calculate the atom location sums for each sample 
// from the MCMC

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void locSums(
  char **DatFL, char **DatVL,               // The filenames for the MCMC output
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *locSum )          // The calculated loc. sum values will be written to locSum
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 

  Array1D<double> locSumArr = li.locSums( (int)(*tempInd) );

  int nSamps = locSumArr.dim();
  for( int i=0; i<nSamps; i++ )
    locSum[i] = locSumArr[i];

  return;
}

}
          


