// Compiled C subroutine to calculate the estimated mean surface at a grid of points

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void meanSurf(
  char **DatFL, char **DatVL,               // The base filename of the MCMC output
  double *xlocs,            // The coordinates of the locations at which the mean surface is desired.
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *z, long *nLocs,  // nLocs is the length of the xlocs and z vectors
  long *sampNum )          // The calculated mean surface values should be written to z.
                           // The index of the sample for which the surface is desired.  If 
                           // negative, the average over all samples is returned.
                                  
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 
  int nLocs_ = (*nLocs);

  Array1D<double> xlocsArr (nLocs_, xlocs),
    zArr (nLocs_);

  zArr = li.meanVals( xlocsArr, (int)(*tempInd), (*sampNum) );

  for( int i=0; i<nLocs_; i++ )
    z[i] = zArr[i];

  return;
}

}
          


