// Compiled C subroutine to calculate the estimated mean surface at a grid of points

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void percentAbove(
  char **DatFL, char **DatVL,               // The base filename of the MCMC output
  double *xlocs,                  // The coordinates of the locations at which the mean surface is desired.
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *z, long *nLocs,
  double *cutoff )                // The calculated mean surface values should be written to z.
                                  // nLocs is the length of the xlocs and z vectors
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 
  int nLocs_ = (*nLocs);

  Array1D<double> xlocsArr (nLocs_, xlocs),
    zArr = li.percentAbove( xlocsArr, (*cutoff), (int)(*tempInd) );

  for( int i=0; i<nLocs_; i++ )
    z[i] = zArr[i];

  return;
}

}
          


