// Compiled C subroutine to obtain a single kernel magnitude (where the
// kernel is chosen at random) from each iteration of the MCMC

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void randZ(
  char **DatFL, char **DatVL,               // The filenames for the MCMC output
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *randZ )          // The random z values will be
			     // written to z
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 

  Array1D<double> randZArr = li.randZ( (int)(*tempInd) );

  int nSamps = randZArr.dim();
  for( int i=0; i<nSamps; i++ )
    randZ[i] = randZArr[i];

  return;
}

}
          


