// Compiled C subroutine to sample from the 
// posterior distribution of the regression 
// parameters in HARK.


#include "HarkSamp.h"
#include <S.h>

#define TNT_BOUNDS_CHECK
//#define DEBUG_REGR

extern "C"{

void regressSample(
     double *response,               // The response vector
     long *nData,                    // The number of observations
     char **rootFile,               // The root filename for the 
                                    // posterior samples from the LARK runs
     char **outFile,                // The output filename
     long *nTemps,
     double *initPredsInd,
     double *priorVar,
     long *nIter,
     long *priorType,
     long *priorInMcmc,
     double *predPenalty)
{

  // Create an array of doubles for the responses
  int i, nData_ = (int) (*nData);
  TNT::Array1D<double> respArr ( nData_ ),
    predPenalty_( 30 );
  TNT::Array1D<int> indArr( 31, 0 );
  for( i=0; i<nData_; i++ )
    respArr[i] = response[i];
  for( i=0; i<30; i++ )
    predPenalty_[i] = predPenalty[i];
  for( i=0; i<31; i++ )
    indArr[i] = (int)initPredsInd[i];
  

  #ifdef DEBUG_REGR
    std::cout << "response vector: " << respArr << std::endl;
    std::cout << "rootFile: " << (*rootFile) << std::endl;
    std::cout << "initial preds ind. array: " << indArr << std::endl;
    fflush(stdout);
  #endif

  HarkSamp *regSamp = new HarkSamp( respArr, (*rootFile), (int)(*nTemps), 
				    priorVar, (int)(*priorType),
				    (bool)(*priorInMcmc), predPenalty_ );

  regSamp->sample( (*outFile), indArr, (int)(*nIter));

  return;
}
          
}


