// Compiled C subroutine to obtain the posterior samples for the
// surface height at a single location

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void surfSamps(
  char **DatFL, char **DatVL,               // The base filename of the MCMC output
  double *xloc,            // The coordinate of the location at which the surface samp.s are desired.
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *z, long *nSamps) // nSamps is the length of the z vector
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 
  int nSamps_ = (*nSamps);

  Array1D<double> zArr = li.surfSamps( (*xloc), (int)(*tempInd) );

  for( int i=0; i<nSamps_; i++ )
    z[i] = zArr[i];

  return;
} 

}
          


